@@ -7,7 +7,6 @@
  *
  */
 #include "feedstorage.h"
-#include "kcoreaddons_version.h"
 #include "plugin.h"
 #include "storage.h"
 #include "storagefactory.h"
@@ -16,6 +15,7 @@
 #include <Syndication/Atom/Atom>
 #include <Syndication/Constants>
 
+#include <KPluginMetaData>
 #include <QDateTime>
 #include <QFile>
 #include <QIODevice>
@@ -31,6 +31,7 @@
 
 #include <iostream>
 
+#include <KPluginFactory>
 #include <cassert>
 
 using namespace Akregator;
@@ -299,13 +300,9 @@ static KService::List queryStoragePlugins()
 
 static Plugin *createFromService(const KService::Ptr &service)
 {
-    KPluginLoader loader(*service);
-    KPluginFactory *factory = loader.factory();
+    KPluginFactory *factory = KPluginFactory::loadFactory(KPluginMetaData(service->library())).plugin;
     if (!factory) {
-        qCritical() << QStringLiteral(
-                           " Could not create plugin factory for: %1\n"
-                           " Error message: %2")
-                           .arg(service->library(), loader.errorString());
+        qCritical() << QStringLiteral(" Could not create plugin factory for: %1").arg(service->library());
         return nullptr;
     }
     return factory->create<Akregator::Plugin>();
