@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -10,11 +10,11 @@
 #include <KIO/JobUiDelegate>
 #include <KIO/OpenUrlJob>
 #include <KLocalizedString>
+#include <MessageViewer/ViewerPluginToolManager>
 #include <QVBoxLayout>
-#include <viewerplugintoolmanager.h>
-
-#include <KPIMTextEdit/kpimtextedit/texttospeechwidget.h>
-
+#if KPIMTEXTEDIT_TEXT_TO_SPEECH
+#include <kpimtextedit/texttospeechwidget.h>
+#endif
 #include <KPIMTextEdit/SlideContainer>
 
 #include <WebEngineViewer/FindBarWebEngineView>
@@ -45,7 +45,9 @@ template<typename Arg, typename R, typename C> InvokeWrapper<Arg, R, C> invoke(R
 ArticleViewerWebEngineWidgetNg::ArticleViewerWebEngineWidgetNg(ArticleViewerWebEngine *customViewer, KActionCollection *ac, QWidget *parent)
     : QWidget(parent)
     , mArticleViewerNg(customViewer)
+#if KPIMTEXTEDIT_TEXT_TO_SPEECH
     , mTextToSpeechWidget(new KPIMTextEdit::TextToSpeechWidget(this))
+#endif
     , mSliderContainer(new KPIMTextEdit::SlideContainer(this))
     , mTrackingWarningWidget(new WebEngineViewer::TrackingWarningWidget(this))
 
@@ -62,10 +64,10 @@ void ArticleViewerWebEngineWidgetNg::initializeLayout(KActionCollection *ac)
 {
     auto layout = new QVBoxLayout(this);
     layout->setContentsMargins({});
-
+#if KPIMTEXTEDIT_TEXT_TO_SPEECH
     mTextToSpeechWidget->setObjectName(QStringLiteral("texttospeechwidget"));
     layout->addWidget(mTextToSpeechWidget);
-
+#endif
     mTrackingWarningWidget->setObjectName(QStringLiteral("mTrackingWarningWidget"));
     layout->addWidget(mTrackingWarningWidget);
 
@@ -88,9 +90,7 @@ void ArticleViewerWebEngineWidgetNg::initializeLayout(KActionCollection *ac)
     connect(articleViewerNg(), &ArticleViewerWebEngine::findTextInHtml, this, &ArticleViewerWebEngineWidgetNg::slotFind);
 }
 
-ArticleViewerWebEngineWidgetNg::~ArticleViewerWebEngineWidgetNg()
-{
-}
+ArticleViewerWebEngineWidgetNg::~ArticleViewerWebEngineWidgetNg() = default;
 
 ArticleViewerWebEngine *ArticleViewerWebEngineWidgetNg::articleViewerNg() const
 {
@@ -109,7 +109,9 @@ void ArticleViewerWebEngineWidgetNg::slotFind()
 void ArticleViewerWebEngineWidgetNg::slotSpeakText()
 {
     const QString text = mArticleViewerNg->selectedText();
+#if KPIMTEXTEDIT_TEXT_TO_SPEECH
     mTextToSpeechWidget->say(text);
+#endif
 }
 
 void ArticleViewerWebEngineWidgetNg::saveCurrentPosition()
