@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -22,9 +22,7 @@ AkregatorCentralWidget::AkregatorCentralWidget(QWidget *parent)
     addWidget(mCrashWidget);
 }
 
-Akregator::AkregatorCentralWidget::~AkregatorCentralWidget()
-{
-}
+Akregator::AkregatorCentralWidget::~AkregatorCentralWidget() = default;
 
 bool AkregatorCentralWidget::previousSessionCrashed() const
 {
